#####################################################################
# Application 2 -- P-hacking across different disciplines
# Paper: Detecting p-hacking
# Authors: G. Elliott, N. Kudrin, K. Wuthrich
#####################################################################
#The following packages need to be installed!
# install.packages("NlcOptim")
# install.packages("fdrtool")
# install.packages("pracma")
# install.packages("gdata")
# install.packages("spatstat")
# install.packages("rddensity")
# install.packages("ggplot2")

rm(list = ls())
# Set your working directory (it has to be the folder where you save 'Replication_package')
wd = "YOUR WORKING DIRECTORY"
setwd(wd)

RNGkind(sample.kind = "default")
source("Replication_package/Tests.R")

Data <- read.csv(file="Replication_package/Application 2/Head_et_al_data.csv", header=TRUE, sep=",")

Pd = round(Data$pv, Data$dp) #rounded data
dp = Data$dp #rounding precision
science = Data$science
ids = Data$id

#Specify interval for testing
p_max = 0.15
p_min = 0

Jall=30 # number of bins for all data
Jrnd=15 # number of bins for random draw
#use extra bins for Biological and medical&health sciences
Jallplus = 30 
Jrndplus = 15

fig_titles = c("(a) Full sample (rounded data)", "(b) Full sample (de-rounded data)")

S = levels(science)
fields = c("Biological sciences", "Chemical sciences", "Education" , "Engineering", "Medical and health sciences", "Psychology and cognitive sciences")

for (sampl in c("all", "random")){
    Output = matrix(NA, 15, 6)
      if (sampl == "all"){
        CS_bins = Jall
        extra_bins = Jallplus
      }
    
      if (sampl == "random"){
        CS_bins = Jrnd
        extra_bins = Jrndplus
      }
    
    for (r_type in c("Rounded","Derounded")){
        set.seed(123)
      
        Pu = Pd
        #Derounding
        for (k in 1:max(dp)){
          Pu = Pu + (dp==k)*(runif(length(Pd))-0.5)/(10^k)
        }
        Pu = abs(Pu)
      
      for (i in c(1,2,3,4,5,6)){
          print(i)
          id = ids[science == fields[i]]
          if (sampl == "all"){
            if (r_type=="Rounded"){
              P = Pd[science == fields[i]]
            }
            if (r_type=="Derounded"){
              P = Pu[science == fields[i]]
            } 
          }
          
          if (sampl == "random"){
            Prnd = matrix(0, length(unique(id)))
            uid = unique(id)
            if (r_type=="Rounded"){
              P = Pd[science == fields[i]]
            }
            if (r_type=="Derounded"){
              P = Pu[science == fields[i]]
            } 
            for (j in 1:length(uid)){
              Prnd[j] = sample(P[id==uid[j]], 1)
            }
            P=Prnd
            id=1
          }
          
        p_min_LCM = min(P[P>0])

        Output[1 + 8*(r_type=="Derounded"),i] = specify_decimal(Binomial(P, 0.04,0.05,"c"),3)
        Output[2 + 8*(r_type=="Derounded"),i] = specify_decimal(Fisher(P, p_min,p_max),3)
        Output[3 + 8*(r_type=="Derounded"),i] = specify_decimal(Discontinuity_test(P,0.05),3)
        Output[4 + 8*(r_type=="Derounded"),i] = specify_decimal(CoxShi(P,id,  p_min, p_max, CS_bins+extra_bins*(i==1|i==5), 1, 0),3)
        Output[5 + 8*(r_type=="Derounded"),i] = specify_decimal(LCM(P, p_min_LCM, p_max),3)
        Output[6 + 8*(r_type=="Derounded"),i] = length(P[P<=0.05&P>=0.04])
        Output[7 + 8*(r_type=="Derounded"),i] = length(P[P<=p_max&P>=p_min])
        
        if (i==5 & sampl=="all"){
          Qdf = P[P<=p_max&P>=p_min]
          df <- data.frame(Qdf)
          J=CS_bins+extra_bins*(i==1|i==5)
          bin1 = sum(Qdf<=(p_min+(p_max-p_min)/J))/length(Qdf)
          
          if (r_type == "Rounded"){
          pdf(file = "Replication_package/Application 2/Results/Figure4a.pdf")
          }
          if (r_type == "Derounded"){
            pdf(file = "Replication_package/Application 2/Results/Figure4b.pdf")
          }
          space = 0.06*bin1
          p<-ggplot(df, aes(x = Qdf))+geom_histogram(binwidth = p_max/J, boundary = 0,color="black", fill="white",aes(y = stat(count / length(Qdf))))
          p <- p + theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
                       panel.background = element_blank())
          yloc = bin1-space
          xloc = 0.35*p_max
          sz = 8
          p<-p + annotate("text",x = xloc,y = yloc, size=sz,hjust = 0, label = expression(bold(paste(underline("Test: p-value")))))
          yloc = yloc - space
          p<-p + annotate("text", x = xloc,y = yloc, size=sz,hjust = 0, label = paste0(('Binomial: '), Output[1 + 8*(r_type=="Derounded"),5]))
          yloc = yloc - space
          p<-p + annotate("text",x = xloc,y = yloc, size=sz,hjust = 0, label = paste0(("Fisher's Test: "), Output[2 + 8*(r_type=="Derounded"),5]))
          yloc = yloc - space
          p<-p + annotate("text",x = xloc,y = yloc, size=sz,hjust = 0, label = paste0(("Discontinuity: "), Output[3 + 8*(r_type=="Derounded"),5]))
          yloc = yloc - space
          p<-p + annotate("text",x = xloc,y = yloc, size=sz,hjust = 0, label = paste0("CS1: ", Output[4 + 8*(r_type=="Derounded"),5]))
          yloc = yloc - space
          p<-p + annotate("text",x = xloc,y = yloc, size=sz,hjust = 0, label = paste0("LCM: ", Output[5 + 8*(r_type=="Derounded"),5]))
        
          yloc = yloc - 0.1*bin1
          p<-p + annotate("text",x = xloc,y = yloc, size=sz,hjust = 0, label = paste0("Obs in [0.04, 0.05]: ", Output[6 + 8*(r_type=="Derounded"),5]))
          yloc = yloc - space
          p<-p + annotate("text",x = xloc,y = yloc, size=sz,hjust = 0, label = paste0("Total obs: ", Output[7 + 8*(r_type=="Derounded"),5]))
          p <- p+labs(x = "p-value", y = "Proportion", size = 22)+ggtitle(fig_titles[1 + 1*(r_type=="Derounded")])+theme(plot.title = element_text(face="bold",hjust = 0.5, size=24)) 
          p <-p + theme(text = element_text(size=24),axis.text.x = element_text(angle=0, hjust=0.5))
          print(p)
          
          if (r_type == "Rounded"){
            ggsave(p, file = "Replication_package/Application 2/Results/Figure4a.eps", device="eps")
          }
          if (r_type == "Derounded"){
            ggsave(p, file = "Replication_package/Application 2/Results/Figure4b.eps", device="eps")
          }
          dev.off()
        }
      }
    }
            row_names = c("Rounded", "Binomial", "Fisher's Test","Discontinuity", "CS1", "LCM", "Obs in [0.04, 0.05]", "Total obs", "Derounded", "Binomial", "Fisher's Test","Discontinuity", "CS1", "LCM", "Obs in [0.04, 0.05]", "Total obs")
            Tbl = matrix(NA, 16, 7)
            Tbl[,1] = row_names
            Tbl[2:16,2:7] = Output
            
            if (sampl=="all"){
            write.table(Tbl, sep = ',', file = "Replication_package/Application 2/Results/Table_1.csv", row.names = FALSE, col.names = c("Test", fields))
            }
            if (sampl=="random"){
            write.table(Tbl, sep = ',', file = "Replication_package/Application 2/Results/Table_2.csv", row.names = FALSE, col.names = c("Test", fields))
            }
}
  