#####################################################################
# Data preparation for Application 2
# Paper: Detecting p-hacking
# Authors: G. Elliott, N. Kudrin, K. Wuthrich
#####################################################################
# The first part of this code is taken from Head et al. (2016) 
# "The extent and consequences of p-hacking in science" replication package
# https://datadryad.org/stash/dataset/doi:10.5061/dryad.79d43
set.seed(123)
### Head et al. (2016) code starts here ###

#The following package needs to be installed!
#install.packages("dplyr")
library("dplyr")

rm(list = ls())
# Set your working directory (it has to be the folder where you save 'Replication_package')
wd = "YOUR WORKING DIRECTORY"
setwd(wd)


# Load the functions contained in functions.r
#source("functions.r")

# Load the p values data file, and the file containing the FoR categories for each journal
d <- read.csv("Replication_package/Application 2/The extent and consequences of phacking in science Data/1. TEXT_MINING/raw_data/p.values.csv", row.names=1)
journal.categories <- read.csv("Replication_package/Application 2/The extent and consequences of phacking in science Data/1. TEXT_MINING/raw_data/journal.categories.csv", row.names=1)

# Get rid of papers that did not yield any p values
d <- d[!is.na(d$p.value), ]

# only keep papers with a single DOI (tyipcally we lose ~100K files here)
# NB some papers really have 0 or >1 DOI
d <- d[which(d$num.dois==1),]

# only keep papers for which we have >0 results sections (e.g. reviews and commentaries often have 0 results sections)
d <- d[which(d$num.results.sections > 0),]

# some papers have (legitimately, I've checked) zero authors. Remove these.
d <- d[which(d$num.authors>0),]

# some journals publish large 'supplements' that contain conference many short conference abstracts
# (with results sections) in one file. Remove these
d <- d[-c(grep("(Suppl)", d$file.name)),]

# we have a few records in this dataset in which the journal.name wasn't extracted properly, we fix that here
d$journal.name <- as.character(d$journal.name)
fixed.names <- as.character(d$folder.name[which(is.na(d$journal.name))])
fixed.names <- gsub("_", " ", fixed.names)
d$journal.name[which(is.na(d$journal.name))] <- fixed.names
d$journal.name <- as.factor(d$journal.name)

# now we add in the FoR categories 
journal.categories$journal.name <- journal.categories$Abbreviation
d <- merge(d, journal.categories,by="journal.name")

# Include only exact p values which are less than 0.05
#d <- d[d$p.value < 0.05, ]
d <- d[d$operator == "=", ]

# Now make two more datasets of just the p values from the Abstracts and the Results sections
d.results <- d[d$section == "results", ]
#d.abstracts <- d[d$section == "abstract", ]

### Head et al. (2016) code ends here ###

pv = d.results$p.value
dp = d.results$decimal.places
file_id = d.results$file.name
science = d.results$FoRCode
n = length(pv)

Data <- data.frame(pv = c(pv), dp = c(dp), file_id = c(file_id), science = science)
Data$id <- Data %>% group_by(file_id) %>% group_indices()
Data <- Data %>% select(-file_id)

fields = c("Biological sciences", "Chemical sciences", "Education" , "Engineering", "Medical and health sciences", "Psychology and cognitive sciences")
Data <- Data[(Data$science==fields[1])|(Data$science==fields[2])|(Data$science==fields[3])|(Data$science==fields[4])|(Data$science==fields[5])|(Data$science==fields[6]),]
write.csv(Data, file = "Replication_package/Application 2/Head_et_al_data.csv")