%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Figures 1 and 2
% Paper: Detecting p-hacking
% Authors: G. Elliott, N. Kudrin, K. Wuthrich
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
rng(123)
%% Figure 1
clear all
%Provide a path to the Replication_package folder
% cd PATH
alpha_bar = 0.1;
gp_mu = @(p,mu) exp(((norminv(1-p)).^2 + 2*mu*norminv(1-p) - mu^2)/4)/sqrt(2);

p = linspace(0.0001, 1, 10000);
gp_mu0 = gp_mu(p, 0);
norm0 = integral (@(p) gp_mu(p,0), 0,alpha_bar);

pp = exp(linspace(-20, 0, 1000000));
gp_mu2 = gp_mu(pp, -2.5);
norm2 = integral (@(p) gp_mu(p,-2.5), 0,alpha_bar);

figure(1)
plot(pp, gp_mu2/norm2,'color','black','LineWidth',2)
hold on
plot(p, gp_mu0/norm0, '--', 'color','black','LineWidth',2)

xlim([0 alpha_bar])
ylim([0 50])
set(gca,'FontSize',18)
xlabel('$$p$$', 'FontSize',20,'Interpreter','latex')
ylabel('$$g_{(0,0.1]}(p)$$', 'FontSize',20,'Interpreter','latex')
lgd = legend('\mu = -2.5','\mu = 0');
lgd.FontSize = 20;
saveas(gcf,'Figure_1', 'epsc')

%% Figure 2
clear all
figure(2)
p = linspace(0,0.05, 1000);
cv = norminv(1-p);
I = zeros(length(p), 1);
Inv = zeros(length(p),1);
s = 1;
for j = 1:length(p)
f = @(h) normcdf(norminv(1-p(j)) - h).*2.*normpdf(h, 0, s);
I(j) = integral(f, 0, Inf);
end
gnp = (2/sqrt(1 + s^2)).*exp(cv.^2/(2*(1+s^(-2)))).*normcdf(cv/sqrt(1+s^(-2)));
g5 = (I.^(5-1))*5.*gnp';
g20 = (I.^(20-1))*20.*gnp';
ub = exp(cv.^2/2);
plot(p,g5, '--','LineWidth', 3, 'color', 'black')
hold on
plot(p,g20,':','LineWidth', 3, 'color', 'black')
plot(p,ub, 'LineWidth', 4, 'color', 'black')
set(gca,'FontSize',18)
xlabel('$$p$$', 'FontSize',20, 'Interpreter','latex')
ylabel('$$g^p(p;M)$$', 'FontSize',20,'Interpreter','latex')
ylim([0, 50])
xlim([0, 0.05])
lgd = legend('$M = 5$','$M = 20$','$\mathcal{B}^{(0)}_1(p)$','Interpreter','latex');
lgd.FontSize = 20;
saveas(gcf,'Figure_2', 'epsc')